@@ -2,7 +2,7 @@ import os,sys,time,random,uuid
 
 from dpdispatcher.JobStatus import JobStatus
 from dpdispatcher import dlog
-from dpdispatcher.batch import Batch
+from dpdispatcher.machine import Machine
 
 
 pbs_script_header_template="""
@@ -12,7 +12,7 @@ pbs_script_header_template="""
 {queue_name_line}
 """
 
-class PBS(Batch):
+class PBS(Machine):
     def gen_script(self, job):
         pbs_script = super(PBS, self).gen_script(job)
         return pbs_script
@@ -55,7 +55,7 @@ class PBS(Batch):
             = self.context.block_call ("qstat -x " + job_id)
         err_str = stderr.read().decode('utf-8')
         if (ret != 0) :
-            if str("qstat: Unknown Job Id") in err_str :
+            if str("qstat: Unknown Job Id") in err_str or str("Job has finished") in err_str:
                 if self.check_finish_tag(job=job) :
                     return JobStatus.finished
                 else :
