@@ -15,9 +15,12 @@ from dpdispatcher.pbs import PBS
 from dpdispatcher.slurm import Slurm
 from dpdispatcher.shell import Shell
 from dpdispatcher.lsf import LSF
+
 from dpdispatcher.local_context import _identical_files
+from dpdispatcher.dp_cloud_server import DpCloudServer
+from dpdispatcher.dp_cloud_server_context import DpCloudServerContext
 from dpdispatcher.submission import Submission, Job, Task, Resources
-from dpdispatcher.batch_object import BatchObject, Machine
+from dpdispatcher.machine import Machine
 
 def setUpModule():
     os.chdir(os.path.abspath(os.path.dirname(__file__)))
